%--- Simulation settings ---%
simulation = {
    time = {
        start = 0;      %   [s]     Start time
        end = 10;       %   [s]     End time of simulation
        dt = 1e-4;      %   [s]     Time step size
        cfl = 0.75;    % use adaptive time step based on max courant number
    }
    print = {
        dt = 1e-2;    % save results every xx time interval
        % format = "ascii"
    }
    numLib = {
      qPointsAdded = 2;
    }
    statics = {
      solve = true;
      maxIter = 1000;
      timeStep = 0.001;
      relax = true;
    }
    API = {
      % the order of the API input vector in moodySolve and moodyInit. 
      bcNames = {'bc5','bc6','bc7','bc8'}; 
      syncOutput = 1; % (1)
      staggerTimeFraction = 0.5; % (0) 
      reboot = 'no'; % ('yes')
      output = 'mooring/results'; % (inputFilename without ".extension")
    }
} 


%--- Environmental settings ---%
environment = {
    gravity = -9.81;        % [m/s2]    Gravitational acceleration
    waterLevel = 0.5;         % [m]       z-coordinate of mean water level
    waterDensity = 1e3;     % [kg/m3]   Density of water
    airDensity = 0.0;       % [kg/m3]   Density of air

    %--- Ground model input  ----%
    ground = {
        level = 0;
        type = 'springDamp';
        % damping = 1e4;
        dampingCoeff = 1; % ratio of critical damping for each cable
        frictionCoeff = 0.3;
        frictionVelocity = 0.01;
        stiffness = 3e9;    
        oneWayDamping = 0;     % default is 1, only damping on impact, not in lift. 0 means pure linear damping.                    
    }
    
} % end environment

%---Cable types---%
cableType1 = {
    diameter = 0.025;
    rho = 5000;
    gamma0 = 0.5;
    CDn = 1.6;
    CDt = 0.05;
    CMn = 1.0;
    CMt = 0.0;
    materialModel = {
        EA = 1e3; % specific input to material model.
        xi = 0.5;
        type = 'bilinear';
    }
}

% note that unconnected  vertices are ignored. 
% vertice 5-8 are externally controlled. No need to specify exact value.
%--- List of vertices ---%
%                       no.     x       y       z                     
vertexLocations =       {   
                        1    [-1 -1 0];
			2    [-1 1.9 0];
			3    [2 1.9 0];
			4    [2 -1 0];
			5    [0.35 0.35 0.1];
			6    [0.35 0.55 0.1];
			7    [0.65 0.55 0.1];                            
			8    [0.65 0.35 0.1];
                        };

 %----- Cables -----%

cable1 = {
    typeNumber = 1;
    vertex0 = 1; %
    vertex1 = 5; %
    length = 1.73; %
    IC.type = 'CatenaryStatic'; 
    N =   5;   %
}

cable2 = {
    typeNumber = 1;
    vertex0 = 2; %
    vertex1 = 6; %
    length = 1.73; %
    IC.type = 'CatenaryStatic'; 
    N =   5;   %
}
cable3 = {
    typeNumber = 1;
    vertex0 = 3; %
    vertex1 = 7; %
    length = 1.73; %
    IC.type = 'CatenaryStatic'; 
    N =   5;   %
}
cable4 = {
    typeNumber = 1;
    vertex0 = 4; %
    vertex1 = 8; %
    length = 1.73; %
    IC.type = 'CatenaryStatic'; 
    N =   5;   %
}

%--- Boundary Conditions ---%
bc1 = {
   vertex = 1;
 }
bc2 = {
    vertex = 2;    
}
bc3 = {
   vertex = 3;    
}
bc4 = {
   vertex = 4;    
}
bc5 = {
   vertex = 5;
   mode = 'externalPoint';
   inDofs = 3;
 }
bc6 = {
   vertex = 6;
   mode = 'externalPoint';
   inDofs = 3;
 }
bc7 = {
   vertex = 7;
   mode = 'externalPoint';
   inDofs = 3;
 }
bc8 = {
   vertex = 8;
   mode = 'externalPoint';
   inDofs = 3;
 }

% ===== END OF FILE ===== %
